@@ -1,8 +1,8 @@
-onestep<-function(x, bend = 1.28, na.rm = FALSE, MED = TRUE){
+onestep<-function(x, bend = 1.28, na.rm = FALSE, MED = TRUE, ...){
   #
   #  Compute one-step M-estimator of location using Huber's Psi.
   #  The default bending constant is 1.28
-  #  
+  #
   #  MED=TRUE: initial estimate is the median
   #  Otherwise use modified one-step M-estimator
   #
