@@ -60,7 +60,7 @@ pbcor <- function(x, y = NULL, beta = 0.2, ci = FALSE, nboot = 500, alpha = 0.05
   }
   ## end CI
 
-  result <- list(cor=pbcor,test=test,p.value=sig,n=nval, cor_ci = corci, call = cl)
+  result <- list(cor=pbcor,test=test,p.value=sig,n=nval, cor_ci = corci, alpha = alpha, call = cl)
   class(result) <- "pbcor"
   result
 }
