@@ -1,4 +1,4 @@
-winse<-function(x, tr = .2){
+winse<-function(x, tr = .2, ...){
 #
 # Estimate the standard error of the Winsorized mean
 #
@@ -9,4 +9,4 @@ top=(n-1)*sqrt(winvar(x,tr=tr))
 bot=(h-1)*sqrt(n)
 se=top/bot
 se
-}
\ No newline at end of file
+}
