@@ -1,4 +1,4 @@
-winvar <- function(x, tr = 0.2, na.rm = FALSE, STAND = NULL){
+winvar <- function(x, tr = 0.2, na.rm = FALSE, STAND = NULL, ...){
   #
   #  Compute the gamma Winsorized variance for the data in the vector x.
   #  tr is the amount of Winsorization which defaults to .2.
